==> hguDKFZ31.db_2.2.0.tar.gz: hguDKFZ31.db/man/hguDKFZ31_dbconn.Rd <==
\name{hguDKFZ31_dbconn}

\alias{hguDKFZ31_dbconn}
\alias{hguDKFZ31_dbfile}
\alias{hguDKFZ31_dbschema}
\alias{hguDKFZ31_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguDKFZ31_dbconn()
  hguDKFZ31_dbfile()
  hguDKFZ31_dbschema(file="", show.indices=FALSE)
  hguDKFZ31_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguDKFZ31_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hguDKFZ31_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hguDKFZ31_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguDKFZ31_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguDKFZ31_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguDKFZ31_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hguDKFZ31_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguDKFZ31_dbschema}: none (invisible \code{NULL}).

  \code{hguDKFZ31_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguDKFZ31_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguDKFZ31_dbconn() was created with:
  dbConnect(SQLite(), dbname=hguDKFZ31_dbfile(), cache_size=64000, synchronous=0)

  hguDKFZ31_dbschema()

  hguDKFZ31_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hguDKFZ31.db_2.4.5.tar.gz: hguDKFZ31.db/man/hguDKFZ31_dbconn.Rd <==

\name{hguDKFZ31_dbconn}

\alias{hguDKFZ31_dbconn}
\alias{hguDKFZ31_dbfile}
\alias{hguDKFZ31_dbschema}
\alias{hguDKFZ31_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguDKFZ31_dbconn()
  hguDKFZ31_dbfile()
  hguDKFZ31_dbschema(file="", show.indices=FALSE)
  hguDKFZ31_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguDKFZ31_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hguDKFZ31_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hguDKFZ31_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguDKFZ31_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguDKFZ31_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguDKFZ31_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hguDKFZ31_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguDKFZ31_dbschema}: none (invisible \code{NULL}).

  \code{hguDKFZ31_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguDKFZ31_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguDKFZ31_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hguDKFZ31_dbfile(), cache_size=64000,
  synchronous=0)

  hguDKFZ31_dbschema()

  hguDKFZ31_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
